Crate kcr_sonataflow_org

Crate kcr_sonataflow_org 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the sonataflow.org group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

sonataflow.org/v1alpha08

  • SonataFlowBuild
  • SonataFlowPlatform
  • SonataFlow

Modules

v1alpha08